@@ -39,19 +39,18 @@ REQUIREMENTS = [
     'decorator<5; python_version<"3"',
     'backports.functools-lru-cache; python_version<"3"',
     'cloudpickle',
-    'ipykernel<5; python_version<"3"',
-    'ipykernel>=6.9.2; python_version>="3"',
+    'ipykernel>=4.5,<5; python_version<"3"',
+    'ipykernel>=6.23.2,<7; python_version>="3"',
     'ipython<6; python_version<"3"',
-    'ipython>=7.31.1,<8; python_version>="3"',
+    'ipython>=7.31.1,<9,!=8.8.0,!=8.9.0,!=8.10.0,!=8.11.0,!=8.12.0,!=8.12.1; python_version>="3"',
     'jupyter-client>=5.3.4,<6; python_version<"3"',
-    'jupyter-client>=7.1.0; python_version>="3"',
+    'jupyter-client>=7.4.9,<9; python_version>="3"',
     'pyzmq>=17,<20; python_version<"3"',
     'pyzmq>=22.1.0; python_version>="3"',
     'wurlitzer>=1.0.3;platform_system!="Windows"',
 ]
 
 TEST_REQUIREMENTS = [
-    'codecov',
     'cython',
     'dask[distributed]',
     'flaky',
@@ -64,6 +63,7 @@ TEST_REQUIREMENTS = [
     'scipy',
     'xarray',
     'pillow',
+    'django',
 ]
 
 setup(
